# **Olvid Bot Python Client**

## Introduction
Welcome to the Olvid Python Client repository, part of the Olvid bots framework. 
If you're new here, consider starting with our [Documentation](https://doc.bot.olvid.io).

## Installation

You can install this module using pip:

```bash
pip3 install olvid-bot
```

Or from source:

```bash
git clone https://github.com/olvid-io/Olvid-Bot-Python-Client
cd Olvid-Bot-Python-Client
pip3 install .
```

## Overview

This Python module implements a robust gRPC client, designed to simplify interactions while providing complete access to every RPC.
This allows you to achieve advanced tasks with ease.
To see the complete gRPC and protobuf description of the Daemon API, please refer to the [protobuf repository](https://github.com/olvid-io/Olvid-Bot-Protobuf).

The module also includes a built-in **CLI (Command-Line Interface)**, enabling manual interaction with the Daemon for efficient management and testing.
For more information on using the CLI, refer to [README-cli](./README-cli.md).

## Quickstart
Follow our [🚀 Quickstart](https://doc.bot.olvid.io/install) page.
